<?php
/**
 * plugins/autosubscribe/index. -- Displays the main frameset
 *
 * SquirrelMail AutoSubscribe Plugin
 * Copyright (C) 2004-2006 Tomas Kuliavas <tokul@users.sourceforge.net>
 * This program is licensed under GPL. See COPYING for details
 *
 * Redirects to the login page.
 *
 * @version $Id: index.php,v 1.5 2006/08/09 11:22:20 tokul Exp $
 * @package sm-plugins
 * @subpackage autosubscribe
 */
header("Location: ../../src/index.php");
exit();
?>
